@@ -533,7 +533,10 @@ clPairs <- function (data, classification,
     { colors <- rep( "black", l)
       warning("more colors needed")
   }
-	if(is.null(cex)) cex <- rep(1, l) 
+	if(is.null(cex)) cex <- 1
+  if(length(cex) == 1) cex <- rep(cex, l)
+  cex <- cex[1:l]
+  
   grid <- isTRUE(as.logical(grid))
   
   if(d > 2)
@@ -1372,8 +1375,8 @@ vpoints <- function(x, y, col, cex = 1, ...)
 
 crimcoords <- function(data, classification, 
                        numdir = NULL, 
-                       unbiased = FALSE, 
-                       plot = TRUE, ...) 
+                       unbiased = FALSE,
+                       ...) 
 {
   X <- as.matrix(data)
   n <- nrow(X)
@@ -1415,7 +1418,6 @@ crimcoords <- function(data, classification,
               projection = proj,
               classification = classification)
   class(obj) <- "crimcoords"
-  if(plot) plot(obj)
   invisible(obj)
 }
 
@@ -1458,3 +1460,36 @@ plot.crimcoords <- function(x, ...)
   }
   invisible()
 }
+
+summary.crimcoords <- function(object, numdir, ...)
+{
+  if(missing(numdir)) 
+    numdir <- sum(object$evalues > sqrt(.Machine$double.eps))
+  dim <- seq(numdir)
+  obj <- list(basis = object$basis[,seq(dim),drop=FALSE],
+              evalues = object$evalues[seq(dim)],
+              evalues.cumperc = with(object, 
+                                     { evalues <- evalues[seq(numdir)]
+                                       cumsum(evalues)/sum(evalues)*100 })
+              )
+  class(obj) <- "summary.crimcoords"
+  return(obj)
+}
+
+print.summary.crimcoords <- function(x, digits = max(5, getOption("digits") - 3), ...)
+{
+  title <- paste("Discriminant coordinates (crimcoords)")
+  txt <- paste(rep("-", min(nchar(title), getOption("width"))), collapse = "")
+  catwrap(txt)
+  catwrap(title)
+  catwrap(txt)
+  cat("\n")
+  catwrap("Estimated basis vectors:")
+  print(x$basis, digits = digits)
+  cat("\n")
+  evalues <- rbind("Eigenvalues" = x$evalues, 
+                   "Cum. %" = x$evalues.cumperc)
+  colnames(evalues) <- colnames(x$basis)
+  print(evalues, digits = digits)
+  invisible()
+}
